# Bias Adjusment by Quantile Mapping

Bias adjustment techniques:
- Quantile Mapping
- Detrended Quantile Mapping
- Quantile Delta Mapping ([Cannon et al., 2015](https://doi.org/10.1175/JCLI-D-14-00754.1))


## Usage
```python
from bias_adjustment import BiasAdjustment
```
